@@ -10,7 +10,7 @@
 #     UseMethod("estimable")
 #}
 
-mapcalc <- function(estimable, nfac, nruns, res3=FALSE, select.catlg=catlg){
+mapcalc <- function(estimable, nfac, nruns, res3=FALSE, select.catlg=catlg, sort="natural"){
       ## called with checked inputs only --> no checks needed
       ## estimable is a matrix with two rows
       if (ncol(estimable)>nruns - nfac -1) stop("too many interactions requested for this number of runs and factors")
@@ -19,22 +19,29 @@ mapcalc <- function(estimable, nfac, nruns, res3=FALSE, select.catlg=catlg){
           res3 <- FALSE
           }
       catlg <- select.catlg
-     
+
       go2 <- graph.empty(n=nfac,directed=FALSE)
       ## previous version subtracted 1 from estimable for previous igraph node definition; changed 29/06/2012
       go2 <- add.edges(go2,estimable)
-      degree2 <- rev(cumsum(rev(table(degree(go2)))))   ## make it faster to reject non-isomorphic cases
+   ## optionally sort vertices by degree, 20 Jul 2012
+      deg2 <- degree(go2)
+      if (sort %in% c("high","low")){
+        if (sort=="low") ord2 <- order(deg2)
+           else ord2 <- order(deg2, decreasing=TRUE)
+        go2 <- permute.vertices(go2, FrF2:::invperm(ord2))
+      }
+      degree2 <- rev(cumsum(rev(table(deg2))))   ## make it faster to reject non-isomorphic cases
                                       ## 7 Feb 2011
       degs2 <- as.numeric(names(degree2))  ## required minimum degrees
       ## added further pre-filtering criteria 9 July 2012
       indep2 <- independence.number(go2)   ## required maximum independence number
       clique2 <- clique.number(go2)        ## required minimum clique size
       ## reduced attention to dominating designs, if applicable (29 June 2012)
-      tobechecked <- catlg[which(nfac.catlg(catlg)==nfac & nruns.catlg(catlg)==nruns & dominating.catlg(catlg))]
-      if (length(tobechecked)>0) 
-              if (!res3) tobechecked <- tobechecked[which(res.catlg(tobechecked)>=4)]
-      if (length(tobechecked)>0) 
-              tobechecked <- tobechecked[which(nclear.2fis.catlg(tobechecked)>=ncol(estimable))]
+      tobechecked <- catlg[which(nfac(catlg)==nfac & nruns(catlg)==nruns & dominating(catlg))]
+      if (length(tobechecked)>0)
+              if (!res3) tobechecked <- tobechecked[which(res(tobechecked)>=4)]
+      if (length(tobechecked)>0)
+              tobechecked <- tobechecked[which(nclear.2fis(tobechecked)>=ncol(estimable))]
       if (length(tobechecked)==0)
               if (res3)
               stop("The required interactions cannot be accomodated clear of aliasing in ", nruns, " runs.")
@@ -44,15 +51,23 @@ mapcalc <- function(estimable, nfac, nruns, res3=FALSE, select.catlg=catlg){
               else
               stop("No resolution IV or higher design from the current catalogue can accomodate the required interactions clear of aliasing in ", nruns, " runs.")
               }
-      
+
       map <- NULL
-## warum hier assign to global env.?
+    ## .FrF2.currentlychecked is assigned to global env.
+    ## for enabling user to access it after aborting without success
       for (i in 1:length(tobechecked)){
           assign(".FrF2.currentlychecked", names(tobechecked[i]), envir = .GlobalEnv)
           go1 <- graph.empty(n=nfac,directed=FALSE)
           ## previous version subtracted 1 from tobechecked[[i]]$clear.2fis for previous igraph node definition; changed 29/06/2012
           go1 <- add.edges(go1, tobechecked[[i]]$clear.2fis)
-          degree1 <- rev(cumsum(rev(table(degree(go1)))))
+   ## optionally sort vertices by degree, 20 Jul 2012
+          deg1 <- degree(go1)
+      if (sort %in% c("high","low")){
+          if (sort=="low") ord1 <- order(deg1)
+               else ord1 <- order(deg1, decreasing=TRUE)
+          go1 <- permute.vertices(go1, FrF2:::invperm(ord1))
+    }
+          degree1 <- rev(cumsum(rev(table(deg1))))
           degs1 <- as.numeric(names(degree1))
           if (max(degs2) <= max(degs1)){
              ## check for no chance, 7.2.2011
@@ -65,25 +80,32 @@ mapcalc <- function(estimable, nfac, nruns, res3=FALSE, select.catlg=catlg){
           if (clique.number(go1) < clique2) next
           erg <- graph.subisomorphic.vf2(go1,go2)
           ## +1 removed from map21 because of adapting to igraph (29 June 2012)
-          if (erg$iso) {map <- list(erg$map21)
+          if (erg$iso) {
+                    map <- list(erg$map21)
+                    if (sort %in% c("high","low"))
+                       map <- list(ord1[map[[1]]][FrF2:::invperm(ord2)])
                     names(map) <- get(".FrF2.currentlychecked")
                     rm(.FrF2.currentlychecked, envir = .GlobalEnv)
-                    break}
+                    break
+                    }
         }
      }
-     if (is.null(map)) 
+     if (is.null(map))
               if (res3)
               stop( "The required interactions cannot be accomodated clear of aliasing in ", nruns, " runs." )
               else{
               if (nruns <= 64)
               stop( "The required interactions cannot be accomodated clear of aliasing in ", nruns, " runs with resolution IV or higher." )
               else
-              stop( "No resolution IV or higher design from the current catalogue can accomodate the required interactions clear of aliasing in ", 
+              stop( "No resolution IV or higher design from the current catalogue can accomodate the required interactions clear of aliasing in ",
                    nruns, " runs." )
               }
      map
 }
-##map <-mapcalc(9,64,matrix(c(1,2,1,3,1,4,2,3,3,5,4,8,3,7),2,7))
+##map <-FrF2:::mapcalc(matrix(c(1,2,1,3,1,4,2,3,3,5,4,8,3,7),2,7),9,64)
+#print(FrF2:::mapcalc(matrix(c(1,2,1,3,1,4,1,5,3,5,4,5,5,7),2,7),9,32,sort="low"))
+#print(FrF2:::mapcalc(matrix(c(1,2,1,3,1,4,1,5,3,5,4,5,5,7),2,7),9,32,sort="high"))
+#print(FrF2:::mapcalc(matrix(c(1,2,1,3,1,4,1,5,3,5,4,5,5,7),2,7),9,32))
 
 mapcalc.distinct <- function(estimable, nfac, nruns, res3=FALSE, max.time=60, select.catlg=catlg, perm.start=1:nfac, perms=NULL){
 ## words of length three not correctly represented yet
@@ -336,12 +358,13 @@ estimable.check <- function(estimable,nfac,factor.names){
 
 estimable <- function(estimable, nfac, nruns, 
                       clear=FALSE, res3=FALSE, max.time=60, 
-                      select.catlg=catlg, perm.start=1:nfac, perms=NULL,
-                      order = 3){
+                      select.catlg=catlg, 
+                      perm.start=1:nfac, perms=NULL,
+                      order = 3, sort="natural"){
         if (clear) {
             ## perhaps relabel estimable entries such that most frequently occurring ones in front
             estimable <- 
-            map <- mapcalc(estimable,nfac,nruns,res3=res3, select.catlg=select.catlg)
+            map <- mapcalc(estimable,nfac,nruns,res3=res3, select.catlg=select.catlg, sort=sort)
         }
            else map <- mapcalc.distinct(estimable,nfac,nruns,res3=res3, max.time=max.time, 
                                 select.catlg=select.catlg, perm.start=perm.start, perms=perms)
